#[non_exhaustive]pub enum DataExceptionSubclass {
Show 33 variants
DataException,
StringDataRightTruncation,
NumericValueOutOfRange,
NullValueNotAllowed,
InvalidDatetimeFormat,
SubstringError,
DivisionByZero,
InvalidArgumentForNaturalLogarithm,
InvalidArgumentForPowerFunction,
TrimError,
InvalidCharacterValueForCast,
InvalidTimeZone,
NegativeLimitValue,
InvalidValueType,
ValuesNotComparable,
InvalidDatetimeFunctionFieldName,
InvalidDatetimeFunctionValue,
InvalidDurationFunctionFieldName,
ListDataRightTruncation,
ListElementError,
InvalidDurationFormat,
PathDataRightTruncation,
IncompatibleTemporalInstantUnitGroups,
MultipleAssignmentsToGraphElementProperty,
NodeLabelsBelowSupportedMinimum,
NodeLabelsExceedSupportedMaximum,
EdgeLabelsBelowSupportedMinimum,
EdgeLabelsExceedSupportedMaximum,
NodePropertiesExceedSupportedMaximum,
EdgePropertiesExceedSupportedMaximum,
RecordFieldsDoNotMatch,
RecordDataFieldUnassignable,
MalformedPath,
}Expand description
Table 8 data-exception subclasses used by runtime evaluation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DataException
Generic data exception fallback for genuinely unclassified runtime data failures.
StringDataRightTruncation
String data, right truncation (22001).
NumericValueOutOfRange
Numeric value out of range (22003).
NullValueNotAllowed
Null value not allowed (22004).
InvalidDatetimeFormat
Invalid datetime format (22007).
SubstringError
Substring error (22011).
DivisionByZero
Division by zero (22012).
InvalidArgumentForNaturalLogarithm
Invalid argument for natural logarithm (2201E).
InvalidArgumentForPowerFunction
Invalid argument for power function (2201F).
TrimError
Trim error (22027).
InvalidCharacterValueForCast
Invalid character value for cast (22018).
InvalidTimeZone
Invalid time zone displacement value (22009).
NegativeLimitValue
Negative limit value (22G02).
InvalidValueType
Invalid value type (22G03).
ValuesNotComparable
Values not comparable (22G04).
InvalidDatetimeFunctionFieldName
Invalid date, time, or datetime function field name (22G05).
InvalidDatetimeFunctionValue
Invalid date, time, or datetime function value (22G06).
InvalidDurationFunctionFieldName
Invalid duration function field name (22G07).
ListDataRightTruncation
List data, right truncation (22G0B).
ListElementError
List element error (22G0C).
InvalidDurationFormat
Invalid duration format (22G0H).
PathDataRightTruncation
Path data, right truncation (22G10).
IncompatibleTemporalInstantUnitGroups
Incompatible temporal instant unit groups (22G14).
MultipleAssignmentsToGraphElementProperty
Multiple assignments to a graph element property (22G0M).
NodeLabelsBelowSupportedMinimum
Number of node labels below supported minimum (22G0N).
NodeLabelsExceedSupportedMaximum
Number of node labels exceeds supported maximum (22G0P).
EdgeLabelsBelowSupportedMinimum
Number of edge labels below supported minimum (22G0Q).
EdgeLabelsExceedSupportedMaximum
Number of edge labels exceeds supported maximum (22G0R).
NodePropertiesExceedSupportedMaximum
Number of node properties exceeds supported maximum (22G0S).
EdgePropertiesExceedSupportedMaximum
Number of edge properties exceeds supported maximum (22G0T).
RecordFieldsDoNotMatch
Record fields do not match the target record type on CAST (22G0U).
RecordDataFieldUnassignable
Record data field unassignable (22G0X).
MalformedPath
Malformed path (22G0Z).
Implementations